# Changelog

## [0.2.4a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.2.4a1) (2024-10-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.2.3...0.2.4a1)

**Merged pull requests:**

- fix:standardize\_lang [\#568](https://github.com/OpenVoiceOS/ovos-core/pull/568) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
